---
component-id: ontology-network
name: Polifonia Ontology Network (PON)
description: Top level description of the ontology modules in the Polifonia Ontology Network, with pointers to each of its submodules.
type: Ontology
release-date: 09/05/2023
release-number: v1.0
work-package: 
- WP2
licence:  CC BY 4.0, https://creativecommons.org/licenses/by/4.0/
links:
- https://github.com/polifonia-project/core/
- https://github.com/polifonia-project/musicmeta-ontology
- https://github.com/polifonia-project/musicmeta-ontology 
- https://github.com/polifonia-project/music-representation-ontology
- https://github.com/polifonia-project/source-ontology
- https://github.com/polifonia-project/instrument-ontology
- https://github.com/polifonia-project/tunes-ontology
- https://github.com/polifonia-project/music-projection-ontology
- https://github.com/polifonia-project/organs-ontology
- https://github.com/polifonia-project/cometa-ontology
- https://github.com/polifonia-project/bell-ontology 
- https://github.com/polifonia-project/music-algorithm-ontology 
- https://github.com/polifonia-project/music-analysis-ontology 
- https://github.com/polifonia-project/music-annotation-ontology 
credits:
- https://github.com/albertmeronyo
- https://github.com/valecarriero
- https://github.com/FiorelaCiroku
- https://github.com/jonnybluesman
- https://github.com/delfimpandiani
- https://github.com/andreamust
- https://github.com/n28div
---

# Polifonia Ontology Network

This repository contains links to the Polifonia Ontology Network.

A root ontology module (FULL), stored in this repository, imports all thematic ontology modules of the ontology network.

Thematic and top-level ontology modules are stored in separate repositories of the *Polifonia Project*, and linked here. 

<img width="922" alt="Screenshot 2021-11-04 at 20 22 46" src="https://github.com/polifonia-project/ontology-network/assets/44606182/f2811e40-a694-473c-ad5e-14acaf887ee0">

## Ontology modules of Polifonia Ontology Network

| **Ontology**             | **Prefix** | **Description**                                                                                | **URI**                                                   | **Repository**                                                     |
|--------------------------|------------|------------------------------------------------------------------------------------------------|-----------------------------------------------------------|--------------------------------------------------------------------|
| **FULL**                 | pon:       | The FULL ontology module stored in this repository, which imports all the modules listed here. | https://w3id.org/polifonia/ontology/ontology-network/     | https://github.com/polifonia-project/ontology-network/             |
| **Core**                 | core:      | Elements of general reuse and ontology design patterns.                                        | https://w3id.org/polifonia/ontology/core/                 | https://github.com/polifonia-project/core-ontology                 |
| **Music Meta**           | mm:        | Achieving interoperability of music metadata.                                                  | https://w3id.org/polifonia/ontology/music-meta/           | https://github.com/polifonia-project/musicmeta-ontology            |
| **Music Representation** | mr:        | Foundational model to describe arbitrary musical content.                                      | https://w3id.org/polifonia/ontology/music-representation/ | https://github.com/polifonia-project/music-representation-ontology |
| **Music Instrument**     | mop:       | Instruments and their evolution through time and space.                                        | https://w3id.org/polifonia/ontology/instrument/           | https://github.com/polifonia-project/instrument-ontology           |
| **Source**               | src:       | Representing musical sources and their context of production.                                  | https://w3id.org/polifonia/ontology/source/               | https://github.com/polifonia-project/source-ontology               |
| **Tunes**                | tunes:     | A specialisation of Music Meta for folk music.                                                 | https://w3id.org/polifonia/ontology/tunes/                | https://github.com/polifonia-project/tunes-ontology                |
| **CoMeta**               | com:       | An extension of Music Meta to represent music corpora.                                         | https://w3id.org/polifonia/ontology/cometa/               | https://github.com/polifonia-project/cometa-ontology               |
| **Music Projection**     | mp:        | Achieving interoperability of music notation systems.                                          | https://w3id.org/polifonia/ontology/music-projection/     | https://github.com/polifonia-project/music-projection-ontology     |
| **Organs**               | organ:     | A rich descriptive model of organs and building methods.                                       | https://w3id.org/polifonia/ontology/organs/                | https://github.com/polifonia-project/organs-ontology               |
| **Bells**                | bell:      | Describing bells, bell towers and bell ringers.                                                | https://w3id.org/polifonia/ontology/bells/                 | https://github.com/polifonia-project/bells-ontology                 |
| **Music Algorithm**     | mx:        | Computational methods for music and their parametrisation.                                     | https://w3id.org/polifonia/ontology/music-algorithm/      | https://github.com/polifonia-project/music-algorithm-ontology      |
| **Music Analysis**      | ma:        | Music analysis through reasoning using modal-tonal theories.                                   | https://w3id.org/polifonia/ontology/music-analyis/        | https://github.com/polifonia-project/music-analysis-ontology       |
| **Music Annotation**    | ann:       | A wrapper of ontologies for music annotations (audio, symbolic).                               | https://w3id.org/polifonia/ontology/music-annotation/     | https://github.com/polifonia-project/music-annotation-ontology     |




## Ontology and dataset survey

A survey (included as part of D2.1) reporting existing ontologies with relations to the PON is avaialble [here](d21-ontologies.pdf), and an analogous one about related datasets is [here](d21-datasets.pdf)





